#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright (C) 2007 Søren Roug, European Environment Agency
#
# This is free software.  You may redistribute it under the terms
# of the Apache license and the GNU General Public License Version
# 2 or at your option any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
#
# Contributor(s):
#

import unittest
from odf.opendocument import OpenDocumentPresentation, OpenDocumentText
from odf import style, text
from odf.table import Table, TableColumn, TableRow, TableCell
from odf.element import IllegalChild
from odf.namespaces import TEXTNS

class TestMasterStyles(unittest.TestCase):
    
    def testStyle(self):
        presdoc = OpenDocumentPresentation()
        # We must describe the dimensions of the page
        pagelayout = style.PageLayout(name="MyLayout")
        presdoc.automaticstyles.addElement(pagelayout)
        pagelayout.addElement(style.PageLayoutProperties(margin="0cm", pagewidth="28cm", pageheight="21cm", printorientation="landscape"))

        # Every drawing page must have a master page assigned to it.
        masterpage = style.MasterPage(name="MyMaster", pagelayoutname=pagelayout)
        presdoc.masterstyles.addElement(masterpage)

        # Style for the title frame of the page
        # We set a centered 34pt font with yellowish background
        titlestyle = style.Style(name="MyMaster-title", family="presentation")
        titlestyle.addElement(style.ParagraphProperties(textalign="center"))
        titlestyle.addElement(style.TextProperties(fontsize="34pt"))
        titlestyle.addElement(style.GraphicProperties(fillcolor="#ffff99"))
        presdoc.styles.addElement(titlestyle)

        s = unicode(presdoc.stylesxml(),'UTF-8')
        s.index(u'<style:page-layout style:name="MyLayout"><style:page-layout-properties fo:margin="0cm" fo:page-height="21cm" fo:page-width="28cm" style:print-orientation="landscape"/></style:page-layout>')
        s.index(u'<office:styles><style:style style:name="MyMaster-title" style:display-name="MyMaster-title" style:family="presentation"><style:paragraph-properties fo:text-align="center"/><style:text-properties fo:font-size="34pt"/><style:graphic-properties draw:fill-color="#ffff99"/></style:style></office:styles>')
        s.index(u'<office:master-styles><style:master-page style:name="MyMaster" style:display-name="MyMaster" style:page-layout-name="MyLayout"/></office:master-styles>')

    def testMasterWithHeader(self):
        textdoc = OpenDocumentText()
        pl = style.PageLayout(name="pagelayout")
        textdoc.automaticstyles.addElement(pl)
        mp = style.MasterPage(name="Standard", pagelayoutname=pl)
        textdoc.masterstyles.addElement(mp)
        h = style.Header()
        hp = text.P(text="header try")
        h.addElement(hp)
        mp.addElement(h)
        s = unicode(textdoc.stylesxml(),'UTF-8')
        s.index(u'<office:automatic-styles><style:page-layout style:name="pagelayout"/></office:automatic-styles>')


if __name__ == '__main__':
    unittest.main()
