#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright (C) 2007 Søren Roug, European Environment Agency
#
# This is free software.  You may redistribute it under the terms
# of the Apache license and the GNU General Public License Version
# 2 or at your option any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
#
# Contributor(s):
#

import unittest
from odf.opendocument import OpenDocumentText
from odf import style, text
from odf.table import Table, TableColumn, TableRow, TableCell
from odf.element import IllegalChild
from odf.namespaces import TEXTNS

class TestStyles(unittest.TestCase):
    
    def testStyle(self):
        textdoc = OpenDocumentText()
        tablecontents = style.Style(name="Table Contents", family="paragraph")
        tablecontents.addElement(style.ParagraphProperties(numberlines="false", linenumber="0"))
        textdoc.styles.addElement(tablecontents)
        #self.assertEqual(0,0)

    def testStyleFail(self):
        self.assertRaises(TypeError, style.Style, xname='Table Contents')

    def testBadChild(self):
        tablecontents = style.Style(name="Table Contents", family="paragraph")
        p = text.P(text="x")
        self.assertRaises(IllegalChild, tablecontents.addElement,p)

    def testTextStyleName(self):
        boldstyle = style.Style(name="Bold",family="text")
        boldstyle.addElement(style.TextProperties(attributes={'fontweight':"bold"}))
        text.Span(stylename="Bold",text="This part is bold. ")

    def testBadFamily(self):
        self.assertRaises(ValueError, style.Style, name="Bold",family="incorrect")

class TestQattributes(unittest.TestCase):

    def testAttribute(self):
        standard = style.Style(name="Standard", family="paragraph")
        p = style.ParagraphProperties(qattributes={(TEXTNS,u'enable-numbering'):'true'})
        standard.addElement(p)

    def testAttributeForeign(self):
        textdoc = OpenDocumentText()
        standard = style.Style(name="Standard", family="paragraph")
        p = style.ParagraphProperties(qattributes={(u'http://foreignuri.com',u'enable-numbering'):'true'})
        standard.addElement(p)
        textdoc.styles.addElement(standard)
        s = unicode(textdoc.stylesxml(),'UTF-8')
        s.index(u"""<?xml version='1.0' encoding='UTF-8'?>\n""")
        s.index(u'xmlns:ns28="http://foreignuri.com"')
        s.index(u'<style:paragraph-properties ns28:enable-numbering="true"/>')
        s.index(u'<office:styles><style:style style:name="Standard" style:display-name="Standard" style:family="paragraph">')


if __name__ == '__main__':
    unittest.main()
