#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright (C) 2007 Søren Roug, European Environment Agency
#
# This is free software.  You may redistribute it under the terms
# of the Apache license and the GNU General Public License Version
# 2 or at your option any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
#
# Contributor(s):
#

import unittest
import sys
import os
import StringIO
from odf.odf2xhtml import ODF2XHTML

from odf.opendocument import OpenDocumentText
from odf import style
from odf.text import H, P, Span

htmlout = """<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"><head><meta content="text/html;charset=UTF-8" http-equiv="Content-Type"/>
<meta name="generator" content="ODFPY/0.6"/>
<style type="text/css">
img { width: 100%; height: 100%; }
* { padding: 0; margin: 0; }
h1 {
	font-size: 24pt;
	font-weight: bold;
}
.S-Bold {
	font-weight: bold;
}
</style>
</head>
<body><h1>Simple test document<a name="1.Simple test document"></a>
</h1>
<p>The earth's climate has not changed many times in the course of its long history. <span class="S-Bold">This part is bold. </span>
This is after bold.</p>
</body>
</html>
"""

class TestXHTML(unittest.TestCase):
    
    def setUp(self):
        d = OpenDocumentText()

        # Styles
        h1style = style.Style(name="Heading 1",family="paragraph")
        h1style.addElement(style.TextProperties(attributes={'fontsize':"24pt", 'fontweight':"bold"}))
        d.styles.addElement(h1style)

        boldstyle = style.Style(name="Bold",family="text")
        boldstyle.addElement(style.TextProperties(attributes={'fontweight':"bold"}))
        d.automaticstyles.addElement(boldstyle)

        # Text
        h = H(outlinelevel=1, stylename=h1style, text="Simple test document")
        d.text.addElement(h)
        p = P(text="The earth's climate has not changed many times in the course of its long history. ")
        d.text.addElement(p)
        boldpart = Span(stylename=boldstyle, text="This part is bold. ")
        p.addElement(boldpart)
        p.addText("This is after bold.")

        #   print d.contentxml()
        d.save("TEST.odt")


    def testParsing(self):
        """ Parse the test file """
        odhandler = ODF2XHTML()
        outf = StringIO.StringIO()

        result = odhandler.odf2xhtml("TEST.odt")
        outf.write(result.encode('utf-8'))
        self.assertEqual(outf.getvalue(), htmlout)
        os.unlink("TEST.odt")

if __name__ == '__main__':
    unittest.main()

